@@ -56,6 +56,11 @@ def parse_args():
         "--port",
         help="Port to connect to on host (defaults to standard MinKNOW port based on tls setting)",
     )
+    parser.add_argument(
+        "--api-token",
+        default=None,
+        help="Specify an API token to use, should be returned from the sequencer as a developer API token.",
+    )
     parser.add_argument("--verbose", action="store_true", help="Enable debug logging")
 
     parser.add_argument("--sample-id", help="sample ID to set")
@@ -110,7 +115,9 @@ def parse_args():
 
     # BARCODING ARGUMENTS
     parser.add_argument(
-        "--barcoding", action="store_true", help="protocol uses barcoding",
+        "--barcoding",
+        action="store_true",
+        help="protocol uses barcoding",
     )
     parser.add_argument(
         "--barcode-kits",
@@ -118,7 +125,9 @@ def parse_args():
         help="bar-coding expansion kits used in the experiment",
     )
     parser.add_argument(
-        "--trim-barcodes", action="store_true", help="enable bar-code trimming",
+        "--trim-barcodes",
+        action="store_true",
+        help="enable bar-code trimming",
     )
     parser.add_argument(
         "--barcodes-both-ends",
@@ -159,7 +168,8 @@ def parse_args():
         help="Specify alignment reference to send to basecaller for live alignment.",
     )
     parser.add_argument(
-        "--bed-file", help="Specify bed file to send to basecaller.",
+        "--bed-file",
+        help="Specify bed file to send to basecaller.",
     )
 
     # Output arguments
@@ -190,6 +200,19 @@ def parse_args():
         help="set the number of reads combined into one Fast5 file.",
     )
 
+    parser.add_argument(
+        "--pod5",
+        action="store_true",
+        help="enables Pod5 file output, defaulting to 4000 reads per file, this will store raw data.",
+    )
+
+    parser.add_argument(
+        "--pod5-reads-per-file",
+        type=int,
+        default=4000,
+        help="set the number of reads combined into one Pod5 file.",
+    )
+
     parser.add_argument(
         "--bam",
         action="store_true",
@@ -205,11 +228,15 @@ def parse_args():
 
     # Read until
     parser.add_argument(
-        "--read-until-reference", type=str, help="Reference file to use in read until",
+        "--read-until-reference",
+        type=str,
+        help="Reference file to use in read until",
     )
 
     parser.add_argument(
-        "--read-until-bed-file", type=str, help="Bed file to use in read until",
+        "--read-until-bed-file",
+        type=str,
+        help="Bed file to use in read until",
     )
 
     parser.add_argument(
@@ -278,8 +305,8 @@ def parse_args():
         print("Unable to specify `--alignment-reference` without `--basecalling`.")
         sys.exit(1)
 
-    if not (args.fast5 or args.fastq):
-        print("No output (fast5 or fastq) specified")
+    if not (args.fast5 or args.pod5 or args.bam or args.fastq):
+        print("No output (fast5, pod5, bam or fastq) specified")
 
     return args
 
@@ -524,7 +551,9 @@ def main():
         logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
 
     # Construct a manager using the host + port provided:
-    manager = Manager(host=args.host, port=args.port)
+    manager = Manager(
+        host=args.host, port=args.port, developer_api_token=args.api_token
+    )
 
     experiment_specs = []
     add_sample_sheet_entries(experiment_specs, args)
@@ -549,7 +578,8 @@ def main():
 
         if args.alignment_reference:
             alignment_args = protocols.AlignmentArgs(
-                reference_files=[args.alignment_reference], bed_file=args.bed_file,
+                reference_files=[args.alignment_reference],
+                bed_file=args.bed_file,
             )
 
         basecalling_args = protocols.BasecallingArgs(
@@ -577,6 +607,7 @@ def main():
 
     fastq_arguments = build_output_arguments(args, "fastq")
     fast5_arguments = build_output_arguments(args, "fast5")
+    pod5_arguments = build_output_arguments(args, "pod5")
     bam_arguments = build_output_arguments(args, "bam")
 
     # Now start the protocol(s):
@@ -600,6 +631,7 @@ def main():
             read_until=read_until_args,
             fastq_arguments=fastq_arguments,
             fast5_arguments=fast5_arguments,
+            pod5_arguments=pod5_arguments,
             bam_arguments=bam_arguments,
             disable_active_channel_selection=args.no_active_channel_selection,
             mux_scan_period=args.mux_scan_period,
